@@ -11,7 +11,7 @@ class NamespaceTest extends \PHPUnit\Framework\TestCase {
         return new Namespace_($fqn);
     }
 
-    public function testCreation() {
+    public function testCreation(): void {
         $stmt1 = new Stmt\Class_('SomeClass');
         $stmt2 = new Stmt\Interface_('SomeInterface');
         $stmt3 = new Stmt\Function_('someFunction');
