@@ -12,7 +12,7 @@ class TraitUseAdaptationTest extends \PHPUnit\Framework\TestCase {
         return new TraitUseAdaptation($trait, $method);
     }
 
-    public function testAsMake() {
+    public function testAsMake(): void {
         $builder = $this->createTraitUseAdaptationBuilder(null, 'foo');
 
         $this->assertEquals(
@@ -36,7 +36,7 @@ class TraitUseAdaptationTest extends \PHPUnit\Framework\TestCase {
         );
     }
 
-    public function testInsteadof() {
+    public function testInsteadof(): void {
         $node = $this->createTraitUseAdaptationBuilder('SomeTrait', 'foo')
             ->insteadof('AnotherTrait')
             ->getNode()
@@ -52,7 +52,7 @@ class TraitUseAdaptationTest extends \PHPUnit\Framework\TestCase {
         );
     }
 
-    public function testAsOnNotAlias() {
+    public function testAsOnNotAlias(): void {
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage('Cannot set alias for not alias adaptation buider');
         $this->createTraitUseAdaptationBuilder('Test', 'foo')
@@ -61,7 +61,7 @@ class TraitUseAdaptationTest extends \PHPUnit\Framework\TestCase {
         ;
     }
 
-    public function testInsteadofOnNotPrecedence() {
+    public function testInsteadofOnNotPrecedence(): void {
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage('Cannot add overwritten traits for not precedence adaptation buider');
         $this->createTraitUseAdaptationBuilder('Test', 'foo')
@@ -70,7 +70,7 @@ class TraitUseAdaptationTest extends \PHPUnit\Framework\TestCase {
         ;
     }
 
-    public function testInsteadofWithoutTrait() {
+    public function testInsteadofWithoutTrait(): void {
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage('Precedence adaptation must have trait');
         $this->createTraitUseAdaptationBuilder(null, 'foo')
@@ -78,7 +78,7 @@ class TraitUseAdaptationTest extends \PHPUnit\Framework\TestCase {
         ;
     }
 
-    public function testMakeOnNotAlias() {
+    public function testMakeOnNotAlias(): void {
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage('Cannot set access modifier for not alias adaptation buider');
         $this->createTraitUseAdaptationBuilder('Test', 'foo')
@@ -87,7 +87,7 @@ class TraitUseAdaptationTest extends \PHPUnit\Framework\TestCase {
         ;
     }
 
-    public function testMultipleMake() {
+    public function testMultipleMake(): void {
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage('Multiple access type modifiers are not allowed');
         $this->createTraitUseAdaptationBuilder(null, 'foo')
@@ -96,7 +96,7 @@ class TraitUseAdaptationTest extends \PHPUnit\Framework\TestCase {
         ;
     }
 
-    public function testUndefinedType() {
+    public function testUndefinedType(): void {
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage('Type of adaptation is not defined');
         $this->createTraitUseAdaptationBuilder(null, 'foo')
