@@ -10,7 +10,7 @@ class TraitUseTest extends \PHPUnit\Framework\TestCase {
         return new TraitUse(...$traits);
     }
 
-    public function testAnd() {
+    public function testAnd(): void {
         $node = $this->createTraitUseBuilder('SomeTrait')
             ->and('AnotherTrait')
             ->getNode()
@@ -25,7 +25,7 @@ class TraitUseTest extends \PHPUnit\Framework\TestCase {
         );
     }
 
-    public function testWith() {
+    public function testWith(): void {
         $node = $this->createTraitUseBuilder('SomeTrait')
             ->with(new Stmt\TraitUseAdaptation\Alias(null, 'foo', null, 'bar'))
             ->with((new TraitUseAdaptation(null, 'test'))->as('baz'))
@@ -41,7 +41,7 @@ class TraitUseTest extends \PHPUnit\Framework\TestCase {
         );
     }
 
-    public function testInvalidAdaptationNode() {
+    public function testInvalidAdaptationNode(): void {
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage('Adaptation must have type TraitUseAdaptation');
         $this->createTraitUseBuilder('Test')
