@@ -5,7 +5,7 @@ namespace PhpParser\ErrorHandler;
 use PhpParser\Error;
 
 class CollectingTest extends \PHPUnit\Framework\TestCase {
-    public function testHandleError() {
+    public function testHandleError(): void {
         $errorHandler = new Collecting();
         $this->assertFalse($errorHandler->hasErrors());
         $this->assertEmpty($errorHandler->getErrors());
