@@ -6,7 +6,7 @@ use PhpParser\Node\Stmt\Echo_;
 use PhpParser\ParserFactory;
 
 class NumberTest extends \PHPUnit\Framework\TestCase {
-    public function testRawValue() {
+    public function testRawValue(): void {
         $parser = (new ParserFactory())->createForNewestSupportedVersion();
         $nodes = $parser->parse('<?php echo 1_234;');
 
